Introduction
====

AlbumSample is a sample project which describes all actions that can be invoked to an album: create, delete, update caption, import assets, get album data, get list of albums as well as list of assets for a specific album.  

It includes [CloudGallery](https://github.com/chute/chute-android-components/tree/v2-components/CloudGallery) and [ImageGrid](https://github.com/chute/chute-android-components/tree/v2-components/ImageGrid) libraries.  

![image1](/screenshots/album_sample1.png)![image2](/screenshots/album_sample2.png)![image3](/screenshots/album_sample3.png)![image4](/screenshots/album_sample4.png)


Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.
  
* Add the [CloudGallery component](https://github.com/chute/chute-android-components/tree/master/Cloud%20Gallery) to your project by either copying all the resources and source code or by adding it as an Android Library project.

* Add the [ImageGrid component](https://github.com/chute/chute-android-components/tree/master/Image%20Grid) to your project by either copying all the resources and source code or by adding it as an Android Library project.

* Register the activities, service and application class in the AndroidManifest.xml file:

```
         <application
         android:name=".AlbumSampleApp"
         android:allowBackup="true"
         android:icon="@drawable/ic_launcher"
         android:label="@string/app_name"
         android:theme="@style/AppTheme" >
         <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />

         <activity
            android:name=".activity.AlbumSampleActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
         </activity>
         <activity android:name="com.chute.tutorials.android.albumsample.activity.AlbumListActivity" />
         <activity android:name="com.chute.components.android.gallerylisting.activity.GalleryListingActivity" />
         <activity android:name="com.chute.components.android.imagegrid.activity.ImageGridActivity" />
         <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />
         </application>
```
    

Usage
====


##Application class

Initialize the ImageLoader and Chute credentials from your Chute developer account:

<pre><code>
      private static ImageLoader createImageLoader(Context context) {
    ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.placeholder);
    imageLoader.setDefaultBitmapSize((int) TypedValue.applyDimension(
        TypedValue.COMPLEX_UNIT_DIP, 75, context.getResources()
            .getDisplayMetrics()));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
    mImageLoader = createImageLoader(this);
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    } else {
      return super.getSystemService(name);
    }
  }
</code></pre>
 

##API Calls

###Create an album:
 Set a name on the AlbumModel and pass the model in the following call:
<pre><code>
  AlbumModel album = new AlbumModel();  
  album.setName("Album name");  
  GCAlbums.create(getApplicationContext(), album, new AlbumCreateCallback()).executeAsync();
</code></pre>

###Update an album:
 Set a name on the AlbumModel and pass the model in the following call:
<pre><code>
  AlbumModel album = new AlbumModel();  
  album.setName("Album updated name");  
  GCAlbums.update(getApplicationContext(), album, new AlbumUpdateCallback()).executeAsync();
</code></pre>

###Delete an album:
 Specify the ID of the album to be deleted and pass the AlbumModel on the following call:
<pre><code>
  AlbumModel album = new AlbumModel();  
  album.setId("12345");  
  GCAlbums.delete(getApplicationContext(), album, new AlbumDeleteCallback()).executeAsync();
</code></pre>

###Get an album:
 Specify the album ID for retrieving all data concerning the given album and pass the AlbumModel in the following call:
<pre><code>
  AlbumModel album = new AlbumModel();  
  album.setId("12345");  
  GCAlbums.get(getApplicationContext(), album, new AlbumGetCallback()).executeAsync();
</code></pre>

###Get list of albums:
  The following call returns a list of albums for the currently authenticated user:  
 <code>GCAlbums.list(getApplicationContext(), new AlbumListCallback()).executeAsync();</code>

###Import photo URLs:
 Create a list of photo URLs you wish to import, specify the ID of the album holding the imported photos and pass the list and the AlbumModel in the following call:
<pre><code>
      AlbumModel album = new AlbumModel();  
      album.setId("12345");  
      ArrayList<String> urls = new ArrayList<String>();  
      urls.add("http://goo.gl/iSlTPq");  
      GCAlbums.imports(getApplicationContext(), album, urls, new AlbumImportCallback()).executeAsync(); 
</code></pre>



	    
