Introduction
====

AssetVotesSample is a sample project that enables browsing photos in a gallery and marking photos as favorite.
It includes [Chute SDK](https://github.com/chute/Chute-SDK-V2-Android) and [CloudGallery](https://github.com/chute/chute-android-components/tree/v2-components/CloudGallery) library.  

![image1](/screenshots/asset_votes1.png)![image2](/screenshots/asset_votes2.png)


Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the chute SDK.
  
* Add the [CloudGallery component](https://github.com/chute/chute-android-components/tree/v2-components/CloudGallery) to your project by either copying all the resources and source code or by adding it as an Android Library project.

* Register the activities, service and application class in the AndroidManifest.xml file:

    ```
         <application
          android:name=".AssetVotesApp"
          android:allowBackup="true"
          android:icon="@drawable/ic_launcher"
          android:label="@string/app_name"
          android:theme="@style/AppTheme" >
          <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />

          <activity
            android:name="com.chute.tutorials.android.assetvotessample.activity.AssetVotesActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
          </activity>
          <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />
          </application>
    ```
    

Usage
====


###Application class 

Initialize the ImageLoader, Chute credentials from your Chute developer account and preference classes:

<pre><code>
      private static ImageLoader createImageLoader(Context context) {
    ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.placeholder);
    imageLoader.setDefaultBitmapSize((int) TypedValue.applyDimension(
        TypedValue.COMPLEX_UNIT_DIP, 75, context.getResources()
            .getDisplayMetrics()));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
    mImageLoader = createImageLoader(this);
    AssetVotesPreferences.init(getApplicationContext());
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    } else {
      return super.getSystemService(name);
    }
  }
</code></pre>
 

###AssetHeartTutorialActivity.java

This Activity class contains a GalleryViewFlipper view from the CloudGallery component for browsing assets. Each asset can be marked as favorite by clicking the heart button.  

Using an AlbumModel ID, the following call is being executed:   
<code>GCAssets.list(getApplicationContext(), album, new AlbumAssetsCallback()).executeAsync();</code>  

The list of assets retrieved in the <code>onSuccess()</code> method is passed to the GalleryViewFlipper which starts loading the assets. Another AsyncTask is being executed that gets the number of hearts for the given asset:   
<code>GCHearts.get(getApplicationContext(), album, assetModel, new GetHeartsCallback()).executeAsync();</code>

When the heart button is clicked, the asset is marked/unmarked as favorite in <code>onPhotoChanged(int index, AssetModel asset)</code> method from the CloudGallery component GalleryCallback interface.  

Hearting/Unhearting assets is done by executing the following calls:  

<code>GCHearts.heart(getApplicationContext(), album, asset, new HeartCallback()).executeAsync();</code>  
<code>GCHearts.unheart(getApplicationContext(), album, asset, new UnheartCallback()).executeAsync();</code>






	    
