Introduction
====

CloudGallerySample is a sample project that shows how to use the [CloudGallery component](https://github.com/chute/chute-android-components/tree/v2-components/CloudGallery).  
It includes [Chute SDK library](https://github.com/chute/Chute-SDK-V2-Android) as well as [CloudGallery library](https://github.com/chute/chute-android-components/tree/master/Cloud%20Gallery). 

![image1](/screenshots/cloud_gallery1.png)![image2](/screenshots/cloud_gallery2.png)


Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.
  
* Add the [CloudGallery component](https://github.com/chute/chute-android-components/tree/v2-components/CloudGallery) to your project by either copying all the resources and source code or by adding it as an Android Library project.

* Register the activities, service and application class in the AndroidManifest.xml file:

    ```
         <application
        android:name=".CloudGallerySampleApp"
        android:allowBackup="true"
        android:icon="@drawable/ic_launcher"
        android:label="@string/app_name"
        android:theme="@style/AppTheme" >
        <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />

        <activity
            android:name="com.chute.tutorials.android.cloudgallerysample.activity.CloudGallerySampleActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
        </activity>
        <activity android:name="com.chute.tutorials.android.cloudgallerysample.activity.GalleryActivity" />
        <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />
        </application>
    ```

Usage
====

###CloudGallerySampleApp.java 

Initialize the ImageLoader and Chute credentials from your Chute developer account, extending the Application class:

<pre><code>
public class CloudGallerySampleApp extends Application {

  private static ImageLoader createImageLoader(Context context) {
    final ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.transparent_image);
    imageLoader.setDefaultBitmapSize(Utils.pixelsFromDp(context, 75));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    mImageLoader = createImageLoader(getApplicationContext());
     Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    }
    return super.getSystemService(name);
  }
}
</code></pre>


You can also extend CloudGalleryApp from CloudGallery component where the ImageLoader is already initialized:

<pre><code>
public class CloudGallerySampleApp extends CloudGalleryApp {

 @Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
  }

}
</code></pre>


###GalleryActivity.java

Get all assets within an album by creating an AlbumModel with a specific album ID set and pass the AlbumModel on the following call:
<pre><code>
AlbumModel album = new AlbumModel();
album.setId("12345");
GCAssets.list(getApplicationContext(), album, new AlbumAssetsCallback()).executeAsync();
</code></pre>

In the <code>onSuccess(ListResponseModel<AssetModel> responseData)</code> method of the AlbumAssetsCallback a list of assets is returned. 
In order to create a gallery and browse the assets, the asset list is passed to GalleryViewFlipper from the CloudGallery component which starts loading the assets.

<pre><code>
private final class AlbumAssetsCallback implements
      HttpCallback<ListResponseModel<AssetModel>> {

    @Override
    public void onSuccess(ListResponseModel<AssetModel> responseData) {
      gallery.setAssetCollection(responseData.getData());

    }

    @Override
    public void onHttpError(ResponseStatus responseCode) {
      ALog.d("An error occurred: " + responseCode.getStatusCode() + "-" + responseCode.getStatusMessage());
    }
  }

</code></pre>


###GalleryViewFlipper

The GalleryViewFlipper uses GalleryCallback interface for easy asset manipulation.

<pre><code>
private final class MyGalleryCallback implements GalleryCallback {

		 @Override
		 public void triggered(GestureEvent event) {
		 }

		 @Override
		 public void onPhotoChanged(int index, GCAssetModel asset) {
		 }

		 @Override
		 public void onPhotoChangeError(PhotoChangeErrorType error) {
		 }

	}
</code></pre>

<code>triggered(GestureEvent event)</code> method can perform actions on different gestures using the GestureEvent object like: single tap, double tap, swipe left, swipe right, swipe top and swipe bottom.  
<code>onPhotoChanged(int index, GCAssetModel asset)</code> method can be used for various actions that include asset position and AssetModel.  
<code>onPhotoChangeError(PhotoChangeErrorType error)</code> method can be used for handling errors occuring if there is no previous or next item and general error.  






