Introduction
====

ImageLoaderSample is a sample project that shows how to use the SDK ImageLoader. 
This sample shows an image from SDcard, URL and Chute photo URL using the SDK ImageLoader.  
It includes [Chute SDK library](https://github.com/chute/Chute-SDK-V2-Android).

![image1](/screenshots/image_loader_sample1.png)![image2](/screenshots/image_loader_sample2.png)


Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.
  
* Register the activities, service and application class into the AndroidManifest.xml file:

    ```
        <application
        android:name=".ImageLoaderSampleApp"
        android:allowBackup="true"
        android:icon="@drawable/ic_launcher"
        android:label="@string/app_name"
        android:theme="@style/AppTheme" >
        <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />

        <activity
            android:name=".activity.ImageLoaderSampleActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
         </activity>
         <activity android:name=".activity.LoadImageActivity" />
         <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />
         </application>
    ```


Usage
====

##Application class

Initialize the ImageLoader and Chute credentials from your Chute developer account:

<pre><code>
private static ImageLoader createImageLoader(Context context) {
    ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.placeholder);
    imageLoader.setDefaultBitmapSize((int) TypedValue.applyDimension(
        TypedValue.COMPLEX_UNIT_DIP, 75, context.getResources()
            .getDisplayMetrics()));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
    mImageLoader = createImageLoader(this);
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    } else {
      return super.getSystemService(name);
    }
  }
</code></pre>

##ImageLoader

Get an instance of the loader for binding the image:
<pre><code>
ImageLoader imageLoader = ImageLoader.get(context);
</code></pre>

The ImageLoader displays an image using its <code>displayImage(String url, ImageView imageView, ImageLoaderListener listener);</code> method containing String value representing the URL as an argument, ImageView where the image is placed and ImageLoaderListener indicating the image loading is finished.

<pre><code>
loader.displayImage(url, imageView, listener);
</code></pre>

You can also specify the width and height of the image:

<pre><code>
loader.displayImage(Utils.getCustomSizePhotoURL(url, height, width), imageView, listener);
</code></pre>

Pass in the ImageLoaderListener if you need to execute a certain task when the loading of the image is complete. 


