Introduction
====

ImageSharerSample is a sample project that shows how to use the ImageSharer component. It includes [Chute SDK library](https://github.com/chute/Chute-SDK-V2-Android) as well as [ImageSharer library](https://github.com/chute/chute-android-components/tree/v2-components/ImageSharer). 
This sample project demonstrates how to share an asset with Facebook, Twitter or via Email.

![image1](/screenshots/image_sharer1.png)![image2](/screenshots/image_sharer2.png)![image3](/screenshots/image_sharer3.png)![image4](/screenshots/image_sharer4.png)![image5](/screenshots/image_sharer5.png)

Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.
  
* Add the [ImageSharer component](https://github.com/chute/chute-android-components/tree/v2-components/ImageSharer) to your project by either copying all the resources and source code or by adding it as an Android Library project.

* Register the activities, service and the application class in the AndroidManifest.xml file:

    ```
         <application
        android:name=".ShareViewSampleApp"
        android:allowBackup="true"
        android:icon="@drawable/ic_launcher"
        android:label="@string/app_name"
        android:theme="@style/AppTheme" >
        <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />

        <activity
            android:name=".ShareViewSampleActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
        </activity>
        <activity android:name="com.chute.components.android.imagesharer.activity.ShareActivity" >
        </activity>
        <activity android:name="com.chute.components.android.imagesharer.activity.DialogActivity" >
        </activity>
        <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />
        </application>
    ```

Usage
====

###Application class
Initialize the ImageLoader and Chute credentials from your Chute developer account, extending the Application class:

<pre><code>
public class ShareViewSampleApp extends Application {

  private static ImageLoader createImageLoader(Context context) {
    final ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.placeholder);
    imageLoader.setDefaultBitmapSize(Utils.pixelsFromDp(context, 75));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    mImageLoader = createImageLoader(getApplicationContext());
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    }
    return super.getSystemService(name);
  }
}
</code></pre>


You can also extend ImageSharerApp from ImageSharer component where the ImageLoader is already initialized:

<pre><code>
public class ShareViewSampleApp extends ImageSharerApp {

 @Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
  }

}
</code></pre>

###Share Asset URL

Facebook and Twitter share the asset URL in a WebView:

<pre><code>
webView.loadUrl(String.format("http://www.facebook.com/sharer.php?u=%s&t=%s", URLEncoder.encode(assetUrl, "UTF-8"), ""));
webView.loadUrl(String.format("http://twitter.com/?status=%s", URLEncoder.encode(assetUrl, "UTF-8"), ""));
</code></pre>
 
"Share via Email" shows a standard email sheet with a preset message and subject that are editable:
  
<pre><code>
private class OnEmailClickListener implements OnClickListener {

    @Override
    public void onClick(View v) {
      String body = getString(R.string.share_email_body);
      body = String.format(body, albumName, assetShareUrl);
      IntentUtil.sendEmail(v.getContext(), null, null, body);
    }
  }
</code></pre>
  
