Introduction
====

ImageUploaderSample is a sample project for uploading a photo. It gets an image from the assets folder and uploads the image in an album. It includes [Chute SDK library](https://github.com/chute/Chute-SDK-V2-Android).

![image1](/screenshots/image_uploader_sample1.png)![image2](/screenshots/image_uploader_sample2.png)
            
Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.
  
* Register the activities, service and application class in the AndroidManifest.xml file:

    ```
        <application
        android:name=".ImageUploaderApp"
        android:allowBackup="true"
        android:icon="@drawable/ic_launcher"
        android:label="@string/app_name"
        android:theme="@style/AppTheme" >
        <activity
            android:name=".activity.UploadActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
        </activity>
        <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />

        <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />
        </application>
    ```
  
  
Usage
====

###Application class
Initialize the ImageLoader and Chute credentials from your Chute developer account, extending the Application class:

<pre><code>
public class ImageUploaderApp extends Application {
 private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    mImageLoader = createImageLoader(this);
    Chute.init(this, new AuthConstants(CLIENT_ID, CLIENT_SECRET), TOKEN);
  }

  private static ImageLoader createImageLoader(Context context) {
    ImageLoader imageLoader = new ImageLoader(context, R.drawable.ic_launcher);
    imageLoader.setDefaultBitmapSize((int) TypedValue.applyDimension(
        TypedValue.COMPLEX_UNIT_DIP, 75, context
            .getResources().getDisplayMetrics()));
    return imageLoader;
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    } else {
      return super.getSystemService(name);
    }
  }
}
</code></pre>

###Photo Uploading

Create a file you wish to upload. In this sample project an image from the assets folder is copied on SDCard: 
<pre><code>
File file = copyAsset(getApplicationContext(), "android.jpg");

public static File copyAsset(final Context context, final String filename)
      throws IOException {
    final AssetManager assetManager = context.getAssets();
    InputStream in = null;
    OutputStream out = null;
    in = assetManager.open(filename);
    final File outFile = new File(
        Environment.getExternalStorageDirectory(), filename);
    out = new FileOutputStream(outFile);
    copyFile(in, out);
    in.close();
    in = null;
    out.flush();
    out.close();
    return outFile;

  }
</code></pre>

Specify the ID of the album to upload the photo to and pass the file path and AlbumModel on the following call:
<pre><code>
  AlbumModel album = new AlbumModel();  
  album.setId("12345");  
 GCAssets.upload(getApplicationContext(), new UploadProgressListenerImplementation(), album, file.getAbsolutePath(), new UploadOneStepCallback()).executeAsync();
</code></pre>

UploadProgressListenerImplementation is an implementation of the UploadProgressListener interface which provides methods triggered when the upload is started, in progress and finished.  

The upload call returns list of assets as a response in its <code>onSuccess(ListResponseModel<AssetModel> responseData);</code> method. These are the assets that have been successfully uploaded.



