Introduction
====

MultiImagePickerSample is a sample project that shows how the MultiImagePicker component is used. It contains [Chute SDK](https://github.com/chute/Chute-SDK-V2-Android) library as well as [MultiImagePicker](https://github.com/chute/chute-android-components/tree/v2-components/MultiImagePicker) library. 
This sample project searches for local device images, shows the images in a grid and creates a list of <code>AssetModel</code>s out of the selected images.

![image1](/screenshots/multi_image_picker1.png)![image2](/screenshots/multi_image_picker2.png)![image3](/screenshots/multi_image_picker3.png)

Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.
  
* Add the [MultiImagePicker component](https://github.com/chute/chute-android-components/tree/v2-components/MultiImagePicker) to your project by either copying all the resources and source code or by adding it as an Android Library project.

* Register the activities and application class in the AndroidManifest.xml file:

    ```
         <application
        android:name=".MultiImagePickerSampleApp"
        android:allowBackup="true"
        android:icon="@drawable/ic_launcher"
        android:label="@string/app_name"
        android:theme="@style/AppTheme" >
        <activity
            android:name=".MultiImagePickerSampleActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
        </activity>
        <activity android:name="com.chute.components.android.multiimagepicker.activity.MultiImagePickerActivity" />
        </application>
    ```

Usage
====

###Application class
Initialize the ImageLoader extending the Application class:

<pre><code>
public class MultiImagePickerSampleApp extends Application {

  private static ImageLoader createImageLoader(Context context) {
    final ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.placeholder);
    imageLoader.setDefaultBitmapSize(Utils.pixelsFromDp(context, 75));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    mImageLoader = createImageLoader(getApplicationContext());
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    }
    return super.getSystemService(name);
  }
}
</code></pre>


You can also extend MultiImagePickerApp from MultiImagePicker component where the ImageLoader is already initialized.

<pre><code>
public class MultiImagePickerSampleApp extends MultiImagePickerApp {
  
}
</code></pre>

 
###MultiImagePickerSampleActivity.java 
This activity class starts the MultiImagePickerAcitivity from the MultiImagePicker component that shows local device images in a grid. After selecting image(s), a result is returned to the activity that started the component i.e. MultiImagePickerSampleActivity.

<pre><code>
@Override
  protected void onActivityResult(int requestCode, int resultCode, Intent data) {
    super.onActivityResult(requestCode, resultCode, data);
    if (requestCode == ChoosePhotosActivityIntentWrapper.ACTIVITY_FOR_RESULT_KEY) {
      if (resultCode == RESULT_OK) {
        ChoosePhotosActivityIntentWrapper wrapper = new ChoosePhotosActivityIntentWrapper(
            data);
        List<AssetModel> assetList = makeAssetList(wrapper
            .getAssetPathList());
        int photosSelected = assetList.size();
        Toast.makeText(getApplicationContext(),
            photosSelected + " photos selected!",
            Toast.LENGTH_SHORT).show();
      } else {
        Toast.makeText(getApplicationContext(), "No photos selected",
            Toast.LENGTH_SHORT).show();
      }
    }
  }
</code></pre>

ChoosePhotosActivityIntentWrapper encapsulates list of selected images paths, from which a list of <code>AssetModel</code>s can be created:

<pre><code>
 public List<AssetModel> makeAssetList(ArrayList<String> gridSelectedFilePath) {
    List<AssetModel> list = new ArrayList<AssetModel>();
    AssetModel asset = new AssetModel();
    for (String filePath : gridSelectedFilePath) {
      asset.setUrl(filePath);
      list.add(asset);
    }
    return list;
  }
</code></pre>
  
