Introduction
====

PhotoCommentsSample is a sample project that shows how the [PhotoComments component](https://github.com/chute/chute-android-components/tree/v2-components/PhotoComments) is used.   
It contains [Chute SDK](https://github.com/chute/Chute-SDK-V2-Android) as well as [PhotoComments](https://github.com/chute/chute-android-components/tree/v2-components/PhotoComments) library. 
This sample project shows how to add comments on an asset. 

![image1](/screenshots/photo_comments1.png)![image2](/screenshots/photo_comments2.png)![image3](/screenshots/photo_comments3.png)

Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.

* Add the [PhotoComments component](https://github.com/chute/chute-android-components/tree/v2-components/PhotoComments) to your project by either copying all the resources and source code or by adding it as an Android Library project.


* Register the activities, service and application class into the AndroidManifest.xml file:

    ```
         <application
        android:name=".PhotoCommentsSampleApp"
        android:allowBackup="true"
        android:icon="@drawable/ic_launcher"
        android:label="@string/app_name"
        android:theme="@style/AppTheme" >
        <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />

        <activity
            android:name=".PhotoCommentsSampleActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
        </activity>
        <activity android:name="com.chute.components.android.photocomments.activity.PhotoCommentsActivity" />
        <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />
        </application>
    ```

Usage
====

###Application class 
Initialize the ImageLoader extending the Application class:

<pre><code>
public class PhotoCommentsSampleApp extends Application {

  private static ImageLoader createImageLoader(Context context) {
    final ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.placeholder);
    imageLoader.setDefaultBitmapSize(Utils.pixelsFromDp(context, 75));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
    mImageLoader = createImageLoader(getApplicationContext());
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    }
    return super.getSystemService(name);
  }
}
</code></pre>


You can also extend PhotoCommentsApp from PhotoComments component where the ImageLoader is already initialized.

<pre><code>
public class PhotoCommentsSampleApp extends PhotoCommentsApp {

@Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
  }
  
}
</code></pre>
 
##API Calls

###Create a comment
Specify album and asset ID of the album and asset holding the comment to be added. Set a name on the CommentModel and pass the comment, album and asset model in the following call:  
<code>GCComments.create(getApplicationContext(), album, asset, comment, new CommentsAddCallback()).executeAsync();</code>

Newly created comment is returned in its <code>onSuccess(ResponseModel<CommentModel> responseData);</code> method.

###List all asset comments
Specify album and asset ID of the album and asset whoose comments you wish to retrieve and pass the album and asset model in the following call:  
<code>GCComments.list(getApplicationContext(), album, asset, new CommentsCallback()).executeAsync();</code>

List of all comments for the specified asset is returned in its <code>onSuccess(ListResponseModel<CommentModel> responseData);</code> method.

###Delete a comment
Specify the comment ID of the comment to be deleted and pass the comment model in the following call:  
<code>GCComments.delete(getApplicationContext(), comment, new CommentDeleteCallback()).executeAsync();</code>


 

	
		    
