/**
 * The MIT License (MIT)

Copyright (c) 2013 Chute

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.chute.tutorials.android.projectsetup;

import com.chute.sdk.v2.api.Chute;
import com.chute.sdk.v2.api.authentication.AuthConstants;
import com.chute.sdk.v2.utils.Utils;

import darko.imagedownloader.ImageLoader;
import android.app.Application;
import android.content.Context;

public class ProjectSetupApp extends Application {

  public static final String TAG = ProjectSetupApp.class.getSimpleName();

  private static ImageLoader createImageLoader(Context context) {
    final ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.ic_launcher);
    imageLoader.setDefaultBitmapSize(Utils.pixelsFromDp(context, 75));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    mImageLoader = createImageLoader(getApplicationContext());
    /**
     * Fill in using "app_id", "app_secret" and "token" value from your Chute
     * application.
     * 
     * See <a href="https://apps.getchute.com">https://apps.getchute.com</a>
     */
    Chute.init(getApplicationContext(), new AuthConstants("app_id", "app_secret"),
        "token");

  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    }
    return super.getSystemService(name);
  }
}
