Introduction
====

SocialGallerySample is a sample project that shows how the SocialGallery component can be used.
It includes [Chute SDK](https://github.com/chute/Chute-SDK-V2-Android) and [SocialGallery](https://github.com/chute/chute-android-components/tree/v2-components/SocialGallery) library.  
This sample project enables browsing photos in a gallery, sharing photos, commenting on photos and marking photos as favorite.

![image1](/screenshots/social_gallery1.png)![image2](/screenshots/social_gallery2.png)![image3](/screenshots/social_gallery3.png)![image4](/screenshots/social_gallery4.png)


Setup
====

* Follow the [ProjectSetup sample](https://github.com/chute/chute-tutorials/tree/master/Android/Project%20Setup) for a complete guide on how to setup the Chute SDK.
  
* Add the [SocialGallery component](https://github.com/chute/chute-android-components/tree/v2-components/SocialGallery) to your project by either copying all the resources and source code or by adding it as an Android Library project.
  
* Register the activities, service and application class in the AndroidManifest.xml file:

    ```
          <application
        android:name=".SocialGallerySampleApp"
        android:allowBackup="true"
        android:icon="@drawable/ic_launcher"
        android:label="@string/app_name"
        android:theme="@style/AppTheme" >
        <service android:name="com.dg.libs.rest.services.HTTPRequestExecutorService" />

        <activity
            android:name="com.chute.tutorials.android.socialgallerysample.SocialGallerySampleActivity"
            android:label="@string/app_name" >
            <intent-filter>
                <action android:name="android.intent.action.MAIN" />

                <category android:name="android.intent.category.LAUNCHER" />
            </intent-filter>
        </activity>
        <activity android:name="com.chute.components.android.socialgallery.activity.SocialGalleryActivity" />
        <activity android:name="com.chute.components.android.imagesharer.activity.ShareActivity" />
        <activity android:name="com.chute.components.android.photocomments.activity.PhotoCommentsActivity" />
        <activity android:name="com.chute.sdk.v2.api.authentication.AuthenticationActivity" />
        </application>
    ```
    
Usage
====

###Application Class 
Initialize the ImageLoader extending the Application class:

<pre><code>
public class SocialGallerySampleApp extends Application {

  private static ImageLoader createImageLoader(Context context) {
    final ImageLoader imageLoader = new ImageLoader(context,
        R.drawable.placeholder);
    imageLoader.setDefaultBitmapSize(Utils.pixelsFromDp(context, 75));
    return imageLoader;
  }

  private ImageLoader mImageLoader;

  @Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
    mImageLoader = createImageLoader(getApplicationContext());
  }

  @Override
  public Object getSystemService(String name) {
    if (ImageLoader.IMAGE_LOADER_SERVICE.equals(name)) {
      return mImageLoader;
    }
    return super.getSystemService(name);
  }
}
</code></pre>


You can also extend PhotoCommentsApp from PhotoComments component where the ImageLoader is already initialized.

<pre><code>
public class SocialGallerySampleApp extends SocialGalleryApp {

@Override
  public void onCreate() {
    super.onCreate();
    Chute.init(getApplicationContext(), new AuthConstants(APP_ID, APP_SECRET), TOKEN);
  }
  
}
</code></pre>


 
###Social Gallery
Get all assets within an album by creating an AlbumModel with a specific album ID set and pass the AlbumModel on the following call:
<pre><code>
AlbumModel album = new AlbumModel();
album.setId("12345");
GCAssets.list(getApplicationContext(), album, new AlbumAssetsCallback()).executeAsync();
</code></pre>

In the <code>onSuccess(ListResponseModel<AssetModel> responseData)</code> method of the AlbumAssetsCallback a list of assets is returned. 
In order to create a gallery and browse the assets, the asset list is passed to GalleryViewFlipper from the CloudGallery component which starts loading the assets.

<pre><code>
private final class AlbumAssetsCallback implements
      HttpCallback<ListResponseModel<AssetModel>> {

    @Override
    public void onSuccess(ListResponseModel<AssetModel> responseData) {
      gallery.setAssetCollection(responseData.getData());

    }

    @Override
    public void onHttpError(ResponseStatus responseCode) {
      ALog.d("An error occurred: " + responseCode.getStatusCode() + "-" + responseCode.getStatusMessage());
    }
  }

</code></pre>


###GalleryViewFlipper

The GalleryViewFlipper uses GalleryCallback interface for easy asset manipulation.

<pre><code>
private final class MyGalleryCallback implements GalleryCallback {

		 @Override
		 public void triggered(GestureEvent event) {
		 }

		 @Override
		 public void onPhotoChanged(int index, GCAssetModel asset) {
		 }

		 @Override
		 public void onPhotoChangeError(PhotoChangeErrorType error) {
		 }

	}
</code></pre>

<code>triggered(GestureEvent event)</code> method can perform actions on different gestures using the GestureEvent object like: single tap, double tap, swipe left, swipe right, swipe top and swipe bottom.  
<code>onPhotoChanged(int index, GCAssetModel asset)</code> method can be used for various actions that include asset position and AssetModel.  
<code>onPhotoChangeError(PhotoChangeErrorType error)</code> method can be used for handling errors occuring if there is no previous or next item and general error.  

###Asset Hearting

When the heart button is clicked, the asset is marked/unmarked as favorite in <code>onPhotoChanged(int index, AssetModel asset)</code> method from the CloudGallery component GalleryCallback interface.  

Hearting/Unhearting assets is done by executing the following calls:  

<code>GCHearts.heart(getApplicationContext(), album, asset, new HeartCallback()).executeAsync();</code>  
<code>GCHearts.unheart(getApplicationContext(), album, asset, new UnheartCallback()).executeAsync();</code>


###Asset Sharing

The share button opens a share dialog with Facebook, Twitter and Email sharing options.  
Facebook and Twitter options for share the asset URL in a WebView:

<pre><code>
webView.loadUrl(String.format("http://www.facebook.com/sharer.php?u=%s&t=%s", URLEncoder.encode(assetUrl, "UTF-8"), ""));
webView.loadUrl(String.format("http://twitter.com/?status=%s", URLEncoder.encode(assetUrl, "UTF-8"), ""));
</code></pre>
 
"Share via Email" shows a standard email sheet with a preset message and subject that are editable:
  
<pre><code>
private class OnEmailClickListener implements OnClickListener {

    @Override
    public void onClick(View v) {
      String body = getString(R.string.share_email_body);
      body = String.format(body, albumName, assetShareUrl);
      IntentUtil.sendEmail(v.getContext(), null, null, body);
    }
  }
</code></pre>


###Asset Comments
The comments button opens comments dialog showing list of all comments for the current asset and option for adding a new comment as well.  

In order to get the list of all comments for a specific asset, set album and asset ID of the album and asset whoose comments you wish to retrieve and pass the album and asset model in the following call:  
<code>GCComments.list(getApplicationContext(), album, asset, new CommentsCallback()).executeAsync();</code>

List of all comments for the specified asset is returned in its <code>onSuccess(ListResponseModel<CommentModel> responseData);</code> method.

Add a new comment by setting album and asset ID of the album and asset holding the comment to be added. Set a name on the CommentModel and pass the comment, album and asset model in the following call:  
<code>GCComments.create(getApplicationContext(), album, asset, comment, new CommentsAddCallback()).executeAsync();</code>

Newly created comment is returned in its <code>onSuccess(ResponseModel<CommentModel> responseData);</code> method.
 
	    
